pub(crate) struct EncodedBlockTransactionList {
transaction_count: usize,
rlp: Bytes,
}Expand description
RLP transaction-list bytes for the execution block.
The roots task already encodes every transaction in EIP-2718 form for the transaction trie. This stores those bytes in the form required by the block body transaction list, so the later full block encoder can copy the transaction-list RLP instead of encoding every transaction again.
Fields
transaction_count: usizerlp: BytesComplete RLP list for the block body transactions field.
Legacy transactions are list elements and typed EIP-2718 transactions are string elements.
Implementations
Sourceimpl EncodedBlockTransactionList
impl EncodedBlockTransactionList
Sourcefn encode_block_with_transactions(
&self,
block: &SealedBlock<Block>,
out: &mut Vec<u8>,
) -> bool
fn encode_block_with_transactions( &self, block: &SealedBlock<Block>, out: &mut Vec<u8>, ) -> bool
Encodes the block with these already encoded transactions when the transaction count matches.
Falls back to a full block encoding if the transaction count does not match.
Returns true if the cached transactions were reused.